@@ -1737,9 +1737,9 @@ bool KBiffImap::command(const TQString& line, unsigned int seq)
     no.sprintf("%d NO", seq);
     
     // must be case insensitive
-    TQRegExp status("\\* STATUS", FALSE);
-    TQRegExp capability("\\* CAPABILITY", FALSE);
-    TQRegExp cram_md5("AUTHENTICATE CRAM-MD5", FALSE);
+    TQRegExp status("\\* STATUS", false);
+    TQRegExp capability("\\* CAPABILITY", false);
+    TQRegExp cram_md5("AUTHENTICATE CRAM-MD5", false);
 
     // are we trying CRAM-MD5 ?
     tried_cram_md5 = cram_md5.search(line)>=0;
@@ -1766,13 +1766,13 @@ bool KBiffImap::command(const TQString& line, unsigned int seq)
          * S: . OK STATUS Completed
          */
         if (status.search(response) >= 0) {
-            TQRegExp unseen("UNSEEN ([0-9]*)", FALSE);
+            TQRegExp unseen("UNSEEN ([0-9]*)", false);
             if (unseen.search(response) >= 0) {
                 TQString num = unseen.cap(1);
                 newMessages = num.toInt();
             }
             
-            TQRegExp number("MESSAGES ([0-9]*)", FALSE);
+            TQRegExp number("MESSAGES ([0-9]*)", false);
             if (number.search(response) >= 0) {
                 TQString num = number.cap(1);
                 messages = num.toInt();
@@ -1787,7 +1787,7 @@ bool KBiffImap::command(const TQString& line, unsigned int seq)
          * S: . OK CAPABILITY completed.
          */
         if (capability.search(response) >= 0) {
-            TQRegExp cram_md5_cap("AUTH=CRAM-MD5", FALSE);
+            TQRegExp cram_md5_cap("AUTH=CRAM-MD5", false);
             if (cram_md5_cap.search(response) >= 0) {
                 auth_cram_md5 = true;
             }
