@@ -8,7 +8,7 @@
 #include "status.h"
 #include "status.moc"
 
-#include <kapp.h>
+#include <tdeapplication.h>
 #include <tdelocale.h>
 
 #include <tqdesktopwidget.h>
@@ -35,7 +35,7 @@ KBiffStatus::KBiffStatus(TQWidget *parent_, const TQString& profile, const KBiff
     _listView->addColumn(i18n("Old"));
     _listView->setColumnAlignment(1, AlignRight);
     _listView->setColumnAlignment(2, AlignRight);
-    _listView->setSorting(1, FALSE);
+    _listView->setSorting(1, false);
     _listView->setFrameStyle(TQFrame::WinPanel | TQFrame::Raised);
     _listView->setVScrollBarMode(TQScrollView::AlwaysOff);
     _listView->setHScrollBarMode(TQScrollView::AlwaysOff);
